SystemOrganization addCategory: #GODProcessorsTests!

TestCase subclass: #PCSStatisticsTests
	instanceVariableNames: 'pcsStatistics aCollection aGODCollection invalidCollection'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODProcessorsTests'!

!PCSStatisticsTests methodsFor: 'initialize-release' stamp: 'TD 10/15/2014 11:44'!
setUp
	"Define local objects for tests"
	|godData|
	pcsStatistics := PCSStatisticsCalculator new.
	aCollection := #(1 3 3 4 4) asBag.
	invalidCollection := #(1 3  'a' 4 4) asBag.
	aGODCollection := Bag new.
	godData := GODData new.
	godData
		title: 'title1';
		width: 1.
	aGODCollection add: godData.
	godData := GODData new.
	godData
		title: 'title2';
		width: 2.
	aGODCollection add: godData.
	godData := GODData new.
	godData
		title: 'title3';
		width: 3.
	aGODCollection add: godData.
		
! !

!PCSStatisticsTests methodsFor: 'testsPass' stamp: 'TD 10/7/2014 19:02'!
testAverage
	"test average"
	self assert: (pcsStatistics average: aCollection) = 3.
	! !

!PCSStatisticsTests methodsFor: 'testsPass' stamp: 'TD 10/15/2014 10:47'!
testAverageKey
	"test average given the key width"
	self assert: (pcsStatistics average: aGODCollection key: [:x | x width]) = 2.
	
	! !

!PCSStatisticsTests methodsFor: 'testsPass' stamp: 'TD 10/15/2014 10:33'!
testCountInOcurrencesOf
	"test mean given the key width"
	|aString aWord|
	aString := 'teste teste2 e ateste'.
	aWord := 'teste'.
	self assert: (pcsStatistics countIn: aString ocurrencesOf: aWord) = 1.! !

!PCSStatisticsTests methodsFor: 'testsPass' stamp: 'TD 10/14/2014 11:15'!
testMedian
	"test median"
	self assert: (pcsStatistics median: aCollection) = 3.
	! !

!PCSStatisticsTests methodsFor: 'testsPass' stamp: 'TD 10/15/2014 13:15'!
testMedianKey
	"test mean given the key width"
	self assert: (pcsStatistics median: aGODCollection key: [:x | x width]) = 2.! !

!PCSStatisticsTests methodsFor: 'testFail' stamp: 'TD 10/15/2014 10:39'!
testNaN
	self should: [pcsStatistics average: invalidCollection.] raise: Error! !

!PCSStatisticsTests methodsFor: 'testsPass' stamp: 'TD 10/20/2014 14:47'!
testStd
	"test standart deviation"
	self assert: (pcsStatistics std: aCollection) = (6/5) sqrt.! !

!PCSStatisticsTests methodsFor: 'testsPass' stamp: 'TD 10/14/2014 13:11'!
testStdKey
	"test mean given the key width"
	self assert: (pcsStatistics std: aGODCollection key: [:x | x width]) = (2/3) sqrt.! !

!PCSStatisticsTests methodsFor: 'testsPass' stamp: 'TD 10/20/2014 14:47'!
testVar
	"test standart deviation"
	self assert: (pcsStatistics var: aCollection) = (6/5).! !

!PCSStatisticsTests methodsFor: 'testsPass' stamp: 'TD 10/15/2014 13:17'!
testVarKey
	"test mean given the key width"
	self assert: (pcsStatistics var: aGODCollection key: [:x | x width]) = (2/3).! !

TestCase subclass: #PCSTaggerTests
	instanceVariableNames: 'aGODData aGODDataCollection pcsTagger aString aStringCollection'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODProcessorsTests'!

!PCSTaggerTests methodsFor: 'initialize-release' stamp: 'TD 10/31/2014 20:26'!
setUp
	|temGODData|
	pcsTagger := PCSTagger new.
	aGODDataCollection := Bag new.
	aGODData := GODData new.
	aGODData
		title: 'title1';
		content: 'Contedo de teste da Classe PCSTagger Contedo PCSTagger';
		width: 1.
	aStringCollection := Bag new.
	aStringCollection add: 'Teste Palavra'.
	aStringCollection add: 'Teste Palavra'.
	aStringCollection add: 'Teste Teste2 Ditongo'.
	aStringCollection add: 'Teste Portugus Palavra Teste2 Ditongo'.
	
	aString := 'Ditongo Teste Portugus Palavra Teste Ditongo Ditongo Ditongo'.
	
	aStringCollection do: [ :str |
		temGODData := GODData new.
		temGODData content: str.
		aGODDataCollection add: temGODData.
	]
! !

!PCSTaggerTests methodsFor: 'testsPass' stamp: 'TD 10/29/2014 13:44'!
testCreateDictTf
	"test method createDictTf"
	|dictTf|
	dictTf := pcsTagger createDictTf: aString.
	self assert: (dictTf at: 'Teste') = 2.
	self assert: (dictTf at: 'Ditongo') = 4.
	self assert: (dictTf at: 'Palavra') = 1.! !

!PCSTaggerTests methodsFor: 'testsPass' stamp: 'TD 10/31/2014 20:46'!
testGetMoreRelevantsOf
	"test tokenizer"
	|tags|
	pcsTagger createDictIdf: aStringCollection.
	"standard relevance := 0.8"
	tags := pcsTagger getMoreRelevantsOf: aString.
	
	self assert: (tags includes: 'Ditongo') = true.
	
	"'Portugus'->0.7134773331462135"
	self assert: (tags includes: 'Portugus') = false. 
	self assert: (tags includes: 'Teste') = false.
	pcsTagger minRelevance: (0.7).
	tags := pcsTagger getMoreRelevantsOf: aString.
	self assert: (tags includes: 'Portugus') = true. 
	self assert: (tags includes: 'Teste') = false.! !

!PCSTaggerTests methodsFor: 'testsPass' stamp: 'TD 10/31/2014 12:43'!
testGetMoreRelevantsOfSingleToken
	"test tokenizer"
	|tags|
	
	
	
	pcsTagger createDictIdf: aStringCollection.
	tags := pcsTagger getMoreRelevantsOf: 'Novidade Teste'.
	
	self assert: (tags includes: 'Novidade') = true.! !

!PCSTaggerTests methodsFor: 'testsPass' stamp: 'TD 10/29/2014 11:32'!
testPreprocess
	|aString bag|
	"test tokenizer"
	aString := 'test tokenizer'.
	bag := Bag new.
	bag add: 'test'.
	bag add: 'tokenizer'.
	
	self assert: (pcsTagger preprocess: aString) = bag.! !

!PCSTaggerTests methodsFor: 'testsPass' stamp: 'TD 10/29/2014 13:47'!
testTokenizer
	|bag|
	bag := #('Palavra' 'Portugus' 'Ditongo' 'Ditongo' 'Ditongo' 'Ditongo' 'Teste' 'Teste') asBag.
	self assert: (pcsTagger tokenizer: aString) = bag.! !

!PCSTaggerTests methodsFor: 'testsPass' stamp: 'TD 10/30/2014 16:42'!
testTrainging
	"must be removed, misspelled"! !

!PCSTaggerTests methodsFor: 'testsPass' stamp: 'TD 10/31/2014 10:08'!
testTraining
	"test tokenizer"
	pcsTagger training: aGODDataCollection.
	self assert: (pcsTagger dictIdf at: 'Teste') = (4/(4+1)) log.
	self assert: (pcsTagger dictIdf at: 'Palavra') = (4/(3+1)) log.
	self assert: (pcsTagger dictIdf at: 'Ditongo') = (4/(2+1)) log.
	self assert: (pcsTagger dictIdf at: 'Portugus') = (4/(1+1)) log.! !

!PCSTaggerTests methodsFor: 'testsPass' stamp: 'TD 10/31/2014 10:05'!
testcreateDictIdf
	"test tokenizer"
	pcsTagger createDictIdf: aStringCollection.
	self assert: (pcsTagger dictIdf at: 'Teste') = (4/(4+1)) log.
	self assert: (pcsTagger dictIdf at: 'Palavra') = (4/(3+1)) log.
	self assert: (pcsTagger dictIdf at: 'Ditongo') = (4/(2+1)) log.
	self assert: (pcsTagger dictIdf at: 'Portugus') = (4/(1+1)) log.! !

!PCSTaggerTests methodsFor: 'testsPass' stamp: 'TD 10/31/2014 11:25'!
testtfIdfWithFrequence
	"test 'tfIdf: WithFrequence:' method"
	pcsTagger createDictIdf: aStringCollection.
	
	self assert: (pcsTagger tfIdf: 'Teste' withFrequence: 4) = ((4/(4+1)) log * 4).
	
	self assert: (pcsTagger tfIdf: 'Ditongo' withFrequence: 2) = (((4 / 3) log) * 2).
	self assert: (pcsTagger tfIdf: 'Portugus' withFrequence: 1) = ((4/2) log) .
	
	
	! !
